@@ -152,11 +152,17 @@ add_plot_attributes <- function(x) {
 
   if (!is.null(obj_name)) {
     # first try, parent frame
-    dat <- tryCatch(get(obj_name, envir = parent.frame()), error = function(e) NULL)
+    dat <- tryCatch(
+      get(obj_name, envir = parent.frame()),
+      error = function(e) NULL
+    )
 
     if (is.null(dat)) {
       # second try, global env
-      dat <- tryCatch(get(obj_name, envir = globalenv()), error = function(e) NULL)
+      dat <- tryCatch(
+        get(obj_name, envir = globalenv()),
+        error = function(e) NULL
+      )
     }
 
     if (is.null(dat)) {
@@ -169,7 +175,6 @@ add_plot_attributes <- function(x) {
     dat <- attr(x, "data", exact = TRUE)
   }
 
-
   if (is.null(dat)) {
     insight::format_error(
       "Failed at retrieving data :( Please provide original model or data through the `data` argument"
@@ -180,10 +185,16 @@ add_plot_attributes <- function(x) {
 }
 
 #' @keywords internal
-.dynGet <- function(x,
-                    ifnotfound = stop(gettextf("%s not found", sQuote(x)), domain = NA, call. = FALSE),
-                    minframe = 1L,
-                    inherits = FALSE) {
+.dynGet <- function(
+  x,
+  ifnotfound = stop(
+    gettextf("%s not found", sQuote(x)),
+    domain = NA,
+    call. = FALSE
+  ),
+  minframe = 1L,
+  inherits = FALSE
+) {
   x <- insight::safe_deparse(x)
   n <- sys.nframe()
   myObj <- structure(list(.b = as.raw(7)), foo = 47L)
