@@ -13,23 +13,26 @@
 #'   geom_point(color = see_colors("lime")) +
 #'   theme_blackboard()
 #' @export
-theme_blackboard <- function(base_size = 11,
-                             base_family = "",
-                             plot.title.size = 1.35 * base_size,
-                             plot.title.face = "plain",
-                             plot.title.space = 1.8 * base_size,
-                             plot.title.position = "plot",
-                             legend.position = "right",
-                             axis.title.space = 1.8 * base_size,
-                             legend.title.size = 1.2 * base_size,
-                             legend.text.size = 1.1 * base_size,
-                             axis.title.size = 1.2 * base_size,
-                             axis.title.face = "plain",
-                             axis.text.size = 1.1 * base_size,
-                             axis.text.angle = NULL,
-                             tags.size = 1.35 * base_size,
-                             tags.face = "bold",
-                             ...) {
+theme_blackboard <- function(
+  base_size = 11,
+  base_family = "",
+  plot.title.size = 1.35 * base_size,
+  plot.title.face = "plain",
+  plot.title.space = 1.8 * base_size,
+  plot.title.position = "plot",
+  legend.position = "right",
+  axis.title.space = 1.8 * base_size,
+  axis.text.space = base_size,
+  legend.title.size = 1.2 * base_size,
+  legend.text.size = 1.1 * base_size,
+  axis.title.size = 1.2 * base_size,
+  axis.title.face = "plain",
+  axis.text.size = 1.1 * base_size,
+  axis.text.angle = NULL,
+  tags.size = 1.35 * base_size,
+  tags.face = "bold",
+  ...
+) {
   theme_modern(
     base_size = base_size,
     base_family = base_family,
@@ -39,6 +42,7 @@ theme_blackboard <- function(base_size = 11,
     plot.title.position = plot.title.position,
     legend.position = legend.position,
     axis.title.space = axis.title.space,
+    axis.text.space = axis.text.space,
     legend.title.size = legend.title.size,
     legend.text.size = legend.text.size,
     axis.title.size = axis.title.size,
