@@ -1,9 +1,11 @@
-.add_prior_layer_ridgeline <- function(model,
-                                       parameter = NULL,
-                                       show_intercept = FALSE,
-                                       alpha_priors = 0.5,
-                                       fill_color = NULL,
-                                       show_ridge_line = TRUE) {
+.add_prior_layer_ridgeline <- function(
+  model,
+  parameter = NULL,
+  show_intercept = FALSE,
+  alpha_priors = 0.5,
+  fill_color = NULL,
+  show_ridge_line = TRUE
+) {
   dat <- tryCatch(
     {
       priors <- bayestestR::simulate_prior(model)
@@ -18,7 +20,9 @@
       x_range <- stats::median(dens$x) + 7 * stats::mad(dens$x) * c(-1, 1)
 
       to_remove <- which(dens$x <= x_range[1] | dens$x >= x_range[2])
-      if (length(to_remove)) dens <- dens[-to_remove, ]
+      if (length(to_remove)) {
+        dens <- dens[-to_remove, ]
+      }
 
       # remove intercept from output, if requested
       .remove_intercept(dens, column = "Parameter", show_intercept)
@@ -92,11 +96,13 @@
 }
 
 
-.add_prior_layer_ribbon <- function(model,
-                                    parameter = NULL,
-                                    show_intercept = FALSE,
-                                    alpha_priors = 0.5,
-                                    fill_color = NULL) {
+.add_prior_layer_ribbon <- function(
+  model,
+  parameter = NULL,
+  show_intercept = FALSE,
+  alpha_priors = 0.5,
+  fill_color = NULL
+) {
   dat <- tryCatch(
     {
       priors <- bayestestR::simulate_prior(model)
@@ -111,7 +117,9 @@
       x_range <- stats::median(dens$x) + 7 * stats::mad(dens$x) * c(-1, 1)
 
       to_remove <- which(dens$x <= x_range[1] | dens$x >= x_range[2])
-      if (length(to_remove)) dens <- dens[-to_remove, ]
+      if (length(to_remove)) {
+        dens <- dens[-to_remove, ]
+      }
 
       # remove intercept from output, if requested
       .remove_intercept(dens, column = "Parameter", show_intercept)
