@@ -3,7 +3,10 @@ test_that("geom and coord functions work correctly", {
   # coord_radar() ------------------
 
   data <- aggregate(iris[1:4], list(Species = iris$Species), mean)
-  data <- datawizard::reshape_longer(data, c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width"))
+  data <- datawizard::reshape_longer(
+    data,
+    c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width")
+  )
 
   set.seed(123)
   vdiffr::expect_doppelganger(
@@ -23,10 +26,16 @@ test_that("geom and coord functions work correctly", {
 
   # geom_point2() ----------------------
 
-  normal <- ggplot2::ggplot(iris, ggplot2::aes(x = Petal.Width, y = Sepal.Length)) +
+  normal <- ggplot2::ggplot(
+    iris,
+    ggplot2::aes(x = Petal.Width, y = Sepal.Length)
+  ) +
     ggplot2::geom_point(size = 8, alpha = 0.3) +
     theme_modern()
-  new <- ggplot2::ggplot(iris, ggplot2::aes(x = Petal.Width, y = Sepal.Length)) +
+  new <- ggplot2::ggplot(
+    iris,
+    ggplot2::aes(x = Petal.Width, y = Sepal.Length)
+  ) +
     geom_point2(size = 8, alpha = 0.3) +
     theme_modern()
 
@@ -41,7 +50,10 @@ test_that("geom and coord functions work correctly", {
   set.seed(123)
   vdiffr::expect_doppelganger(
     title = "`geom_poolpoint()` works - 1",
-    fig = ggplot2::ggplot(iris, ggplot2::aes(x = Petal.Width, y = Sepal.Length, color = Species)) +
+    fig = ggplot2::ggplot(
+      iris,
+      ggplot2::aes(x = Petal.Width, y = Sepal.Length, color = Species)
+    ) +
       geom_poolpoint(label = rownames(iris)) +
       scale_color_flat_d() +
       theme_modern()
@@ -50,7 +62,10 @@ test_that("geom and coord functions work correctly", {
   set.seed(123)
   vdiffr::expect_doppelganger(
     title = "`geom_poolpoint()` works - 2",
-    fig = ggplot2::ggplot(iris, ggplot2::aes(x = Petal.Width, y = Sepal.Length, color = Species)) +
+    fig = ggplot2::ggplot(
+      iris,
+      ggplot2::aes(x = Petal.Width, y = Sepal.Length, color = Species)
+    ) +
       geom_pooljitter(label = rownames(iris)) +
       scale_color_flat_d() +
       theme_modern()
@@ -61,7 +76,10 @@ test_that("geom and coord functions work correctly", {
   set.seed(123)
   vdiffr::expect_doppelganger(
     title = "geom_violindot() works",
-    fig = ggplot2::ggplot(iris, ggplot2::aes(x = Species, y = Sepal.Length, fill = Species)) +
+    fig = ggplot2::ggplot(
+      iris,
+      ggplot2::aes(x = Species, y = Sepal.Length, fill = Species)
+    ) +
       geom_violindot() +
       theme_modern()
   )
@@ -71,7 +89,10 @@ test_that("geom and coord functions work correctly", {
   set.seed(123)
   vdiffr::expect_doppelganger(
     title = "geom_violinhalf() works",
-    fig = ggplot2::ggplot(iris, ggplot2::aes(x = Species, y = Sepal.Length, fill = Species)) +
+    fig = ggplot2::ggplot(
+      iris,
+      ggplot2::aes(x = Species, y = Sepal.Length, fill = Species)
+    ) +
       geom_violinhalf() +
       theme_modern() +
       scale_fill_material_d()
